abaqus2dyna
============

abaqus2dyna is a script to convert, in a limited fashion, Abaqus keyword input  
files to LS-DYNA keyword input files.  It is currently very limited.
(See example.inp)


License
=======

abaqusy2dyna is free software and licensed under the MIT License.


Installation
============

`pip install abaqus2dyna`


Instructions
============

abaqus2dyna.py -i input -o output


Features
========

More to come later...


Info
====

Source code:
https://github.com/tbhartman/abaqus2dyna
